@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Create network transition chord progressions
 
-our $VERSION = '0.0500';
+our $VERSION = '0.0501';
 
 use Carp qw(croak);
 use Data::Dumper::Compact qw(ddc);
@@ -150,7 +150,7 @@ sub generate {
     my $v; # Vertex
     for my $n (1 .. $self->max) {
         $v = $self->_next_successor($n, $v);
-        push @progression, $v;
+        push @progression, $v if $v; # XXX Is this right?
     }
     print "Progression: @progression\n" if $self->verbose;
 
@@ -317,7 +317,7 @@ Music::Chord::Progression - Create network transition chord progressions
 
 =head1 VERSION
 
-version 0.0500
+version 0.0501
 
 =head1 SYNOPSIS
 
